@@ -5,7 +5,7 @@
 package Net::LDAP;
 
 use strict;
-use Socket qw(AF_INET AF_INET6 AF_UNSPEC);
+use Socket qw(AF_INET AF_INET6 AF_UNSPEC SOL_SOCKET SO_KEEPALIVE);
 use IO::Socket;
 use IO::Select;
 use Tie::Hash;
@@ -30,7 +30,7 @@ use Net::LDAP::Constant qw(LDAP_SUCCESS
 
 use constant CAN_IPV6 => eval { require IO::Socket::INET6 } ? 1 : 0;
 
-our $VERSION 	= '0.52';
+our $VERSION 	= '0.53';
 our @ISA     	= qw(Tie::StdHash Net::LDAP::Extra);
 our $LDAP_VERSION 	= 3;      # default LDAP protocol version
 
@@ -105,7 +105,7 @@ sub new {
     my $scheme = $arg->{scheme} || 'ldap';
     my $h = $uri;
     if (defined($h)) {
-      $h =~ s,^(\w+)://,, and $scheme = $1;
+      $h =~ s,^(\w+)://,, and $scheme = lc($1);
       $h =~ s,/.*,,; # remove path part
       $h =~ s/%([A-Fa-f0-9]{2})/chr(hex($1))/eg; # unescape
     }
@@ -119,6 +119,9 @@ sub new {
 
   return undef  unless $obj->{net_ldap_socket};
 
+  $obj->{net_ldap_socket}->setsockopt(SOL_SOCKET, SO_KEEPALIVE, $arg->{keepalive} ? 1 : 0)
+    if (defined($arg->{keepalive}));
+
   $obj->{net_ldap_resp}    = {};
   $obj->{net_ldap_version} = $arg->{version} || $LDAP_VERSION;
   $obj->{net_ldap_async}   = $arg->{async} ? 1 : 0;
